@@ -1,23 +1,10 @@
 #=====================================================================
-# SQL-Ledger Accounting
-# Copyright (c) 2002
+# SQL-Ledger ERP
+# Copyright (c) 2006
 #
 #  Author: DWS Systems Inc.
-#     Web: http://www.sql-ledger.org
+#     Web: http://www.sql-ledger.com
 #
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #======================================================================
 #
 # setup module
@@ -87,14 +74,14 @@ password=
 sub adminlogin {
 
   $form->{title} = qq|SQL-Ledger $form->{version} |.$locale->text('Administration');
-
+  
   $form->header;
   
     print qq|
 <script language="JavaScript" type="text/javascript">
 <!--
 function sf(){
-  document.admin.password.focus();
+  document.forms[0].password.focus();
 }
 // End -->
 </script>
@@ -103,10 +90,10 @@ function sf(){
 
 <div align=center>
 
-<a href="http://www.sql-ledger.org"><img src=sql-ledger.gif border=0></a>
+<a href="http://www.sql-ledger.org"><img src=$images/sql-ledger.gif border=0 target=_blank></a>
 <h1 class=login>|.$locale->text('Version').qq| $form->{version}<p>|.$locale->text('Administration').qq|</h1>
 
-<form method=post action="$form->{script}" name=admin>
+<form method=post action="$form->{script}">
 
 <table>
   <tr>
@@ -120,7 +107,7 @@ function sf(){
 
 </form>
 
-<a href=http://www.sql-ledger.org>SQL-Ledger |.$locale->text('website').qq|</a>
+<a href=http://www.sql-ledger.org target=_blank>SQL-Ledger |.$locale->text('website').qq|</a>
 
 </div>
 
@@ -132,7 +119,7 @@ function sf(){
 
 
 sub create_config {
-  
+
   $form->{sessionkey} = "";
   $form->{sessioncookie} = "";
   
@@ -140,13 +127,13 @@ sub create_config {
     my $t = time + $form->{timeout};
     srand( time() ^ ($$ + ($$ << 15)) );
     $key = "root login$form->{password}$t";
-    
+
     my $i = 0;
     my $l = length $key;
     my $j = $l;
     my %ndx = ();
     my $pos;
-    
+
     while ($j > 0) {
       $pos = int rand($l);
       next if $ndx{$pos};
@@ -163,7 +150,7 @@ sub create_config {
 \%rootconfig = (
 sessionkey => '$form->{sessionkey}'
 );\n\n|;
-  
+
   close CONF;
 
 }
@@ -227,10 +214,9 @@ sub form_footer {
 
   print qq|
 
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
+<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=submit class=submit name=action value="|.$locale->text('Save').qq|">
 $delete
@@ -276,6 +262,7 @@ sub list_users {
 # type=submit $locale->text('Pg Database Administration')
 # type=submit $locale->text('PgPP Database Administration')
 # type=submit $locale->text('Oracle Database Administration')
+# type=submit $locale->text('Sybase Database Administration')
 
   foreach $item (User->dbdrivers) {
     $dbdrivers .= qq|<input name=action type=submit class=submit value="|.$locale->text("$item Database Administration").qq|">|;
@@ -294,6 +281,7 @@ sub list_users {
 
   $form->{title} = "SQL-Ledger ".$locale->text('Accounting')." ".$locale->text('Administration');
 
+
   $form->header;
 
   print qq|
@@ -355,7 +343,6 @@ print qq|
 </table>
 
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <br><input type=submit class=submit name=action value="|.$locale->text('Add User').qq|">
 <input type=submit class=submit name=action value="|.$locale->text('Change Admin Password').qq|">
@@ -386,8 +373,7 @@ sub form_header {
     # get user
     $myconfig = new User "$memberfile", "$form->{login}";
 
-    for (qw(company address signature)) { $myconfig->{$_} = $form->quote($myconfig->{$_}) }
-    for (qw(address signature)) { $myconfig->{$_} =~ s/\\n/\n/g }
+    $myconfig->{signature} =~ s/\\n/\n/g;
 
     # strip basedir from templates directory
     $myconfig->{templates} =~ s/^$templates\///;
@@ -395,22 +381,15 @@ sub form_header {
     $myconfig->{dbpasswd} = unpack 'u', $myconfig->{dbpasswd};
   }
 
-  foreach $item (qw(mm-dd-yy mm/dd/yy dd-mm-yy dd/mm/yy dd.mm.yy yyyy-mm-dd)) {
-    $dateformat .= ($item eq $myconfig->{dateformat}) ? "<option selected>$item\n" : "<option>$item\n";
-  }
-
-  foreach $item (qw(1,000.00 1000.00 1.000,00 1000,00 1'000.00)) {
-    $numberformat .= ($item eq $myconfig->{numberformat}) ? "<option selected>$item\n" : "<option>$item\n";
-  }
+  for (qw(mm-dd-yy mm/dd/yy dd-mm-yy dd/mm/yy dd.mm.yy yyyy-mm-dd)) { $selectdateformat .= "$_\n" }
 
+  for (qw(1,000.00 1000.00 1.000,00 1000,00 1'000.00)) { $selectnumberformat .= "$_\n" }
 
   %countrycodes = User->country_codes;
-  $countrycodes = "";
+  $selectcountrycodes = "";
   
-  foreach $key (sort { $countrycodes{$a} cmp $countrycodes{$b} } keys %countrycodes) {
-    $countrycodes .= ($myconfig->{countrycode} eq $key) ? "<option selected value=$key>$countrycodes{$key}" : "<option value=$key>$countrycodes{$key}";
-  }
-  $countrycodes = qq|<option value="">English\n$countrycodes|;
+  for (sort { $countrycodes{$a} cmp $countrycodes{$b} } keys %countrycodes) { $selectcountrycodes .= "${_}--$countrycodes{$_}" }
+  $selectcountrycodes = qq|--English\n$selectcountrycodes|;
 
   # is there a templates basedir
   if (! -d "$templates") {
@@ -434,23 +413,17 @@ sub form_header {
   push @allhtml, 'Default';
   @allhtml = reverse @allhtml;
   
-  foreach $item (sort @alldir) {
-    if ($item eq $myconfig->{templates}) {
-      $usetemplates .= qq|<option selected>$item\n|;
-    } else {
-      $usetemplates .= qq|<option>$item\n|;
-    }
-  }
+  for (sort @alldir) { $selectusetemplates .= qq|$_\n| }
   
   $lastitem = $allhtml[0];
   $lastitem =~ s/-.*//g;
-  $mastertemplates = qq|<option>$lastitem\n|;
-  foreach $item (@allhtml) {
-    $item =~ s/-.*//g;
+  $selectmastertemplates = qq|$lastitem\n|;
+  for (@allhtml) {
+    $_ =~ s/-.*//g;
     
-    if ($item ne $lastitem) {
-      $mastertemplates .= qq|<option>$item\n|;
-      $lastitem = $item;
+    if ($_ ne $lastitem) {
+      $selectmastertemplates .= qq|$_\n|;
+      $lastitem = $_;
     }
   }
 
@@ -458,29 +431,17 @@ sub form_header {
   @all = grep /.*\.css$/, readdir CSS;
   closedir CSS;
   
-  foreach $item (@all) {
-    if ($item eq $myconfig->{stylesheet}) {
-      $selectstylesheet .= qq|<option selected>$item\n|;
-    } else {
-      $selectstylesheet .= qq|<option>$item\n|;
-    }
-  }
-  $selectstylesheet .= "<option>\n";
+  $selectstylesheet = "\n";
+  for (sort @all) { $selectstylesheet .= qq|$_\n| }
   
   if (%printer && $latex) {
-    $selectprinter = "<option>\n";
-    foreach $item (sort keys %printer) {
-      if ($myconfig->{printer} eq $item) {
-	$selectprinter .= qq|<option value="$item" selected>$item\n|;
-      } else {
-	$selectprinter .= qq|<option value="$item">$item\n|;
-      }
-    }
+    $selectprinter = "\n";
+    for (sort keys %printer) { $selectprinter .= "$_\n" }
 
     $printer = qq|
 	<tr>
 	  <th align=right>|.$locale->text('Printer').qq|</th>
-	  <td><select name=printer>$selectprinter</select></td>
+	  <td><select name=printer>|.$form->select_option($selectprinter, $myconfig->{printer}).qq|</td>
 	</tr>
 |;
 
@@ -510,7 +471,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Name').qq|</th>
-	  <td><input name=name size=15 value="$myconfig->{name}"></td>
+	  <td><input name=name size=15 value="|.$form->quote($myconfig->{name}).qq|"></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('E-mail').qq|</th>
@@ -530,11 +491,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Company').qq|</th>
-	  <td><input name=company size=35 value="$myconfig->{company}"></td>
-	</tr>
-	<tr valign=top>
-	  <th align=right>|.$locale->text('Address').qq|</th>
-	  <td><textarea name=address rows=4 cols=35>$myconfig->{address}</textarea></td>
+	  <td><input name=company size=35 value="|.$form->quote($myconfig->{company}).qq|"></td>
 	</tr>
       </table>
     </td>
@@ -542,11 +499,11 @@ sub form_header {
       <table>
 	<tr>
 	  <th align=right>|.$locale->text('Date Format').qq|</th>
-	  <td><select name=dateformat>$dateformat</select></td>
+	  <td><select name=dateformat>|.$form->select_option($selectdateformat, $myconfig->{dateformat}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Number Format').qq|</th>
-	  <td><select name=numberformat>$numberformat</select></td>
+	  <td><select name=numberformat>|.$form->select_option($selectnumberformat, $myconfig->{numberformat}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Dropdown Limit').qq|</th>
@@ -558,7 +515,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Language').qq|</th>
-	  <td><select name=countrycode>$countrycodes</select></td>
+	  <td><select name=countrycode>|.$form->select_option($selectcountrycodes, $myconfig->{countrycode}, undef, 1).qq|</td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Session Timeout').qq|</th>
@@ -567,12 +524,12 @@ sub form_header {
 
 	<tr>
 	  <th align=right>|.$locale->text('Stylesheet').qq|</th>
-	  <td><select name=userstylesheet>$selectstylesheet</select></td>
+	  <td><select name=userstylesheet>|.$form->select_option($selectstylesheet, $myconfig->{stylesheet}).qq|</select></td>
 	</tr>
 	$printer
 	<tr>
 	  <th align=right>|.$locale->text('Use Templates').qq|</th>
-	  <td><select name=usetemplates>$usetemplates</select></td>
+	  <td><select name=usetemplates>|.$form->select_option($selectusetemplates, $myconfig->{templates}).qq|</select></td>
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('New Templates').qq|</th>
@@ -580,7 +537,7 @@ sub form_header {
 	</tr>
 	<tr>
 	  <th align=right>|.$locale->text('Setup Templates').qq|</th>
-	  <td><select name=mastertemplates>$mastertemplates</select></td>
+	  <td><select name=mastertemplates>|.$form->select_option($selectmastertemplates, $myconfig->{templates}).qq|</select></td>
 	</tr>
 	<input type=hidden name=templates value=$myconfig->{templates}>
       </table>
@@ -613,7 +570,7 @@ sub form_header {
 	</tr>
 	<tr>|;
 
-    if ($item =~ /Pg/) {
+    if ($item =~ /(Pg|Sybase)/) {
       print qq|
 	  <th align=right>|.$locale->text('Dataset').qq|</th>
 	  <td><input name="${item}_dbname" size=15 value=$form->{"${item}_dbname"}></td>
@@ -697,16 +654,14 @@ sub form_header {
 	   );
 	    
   $selectrole = "";
-  foreach $item (qw(user admin supervisor manager)) {
-    $selectrole .= ($myconfig->{role} eq $item) ? "<option selected value=$item>$role{$item}\n" : "<option value=$item>$role{$item}\n";
-  }
+  for (qw(user admin supervisor manager)) { $selectrole .= "$_--$role{$_}\n" }
   
   print qq|
   <tr class=listheading>
     <th colspan=2>|.$locale->text('Access Control').qq|</th>
   </tr>
   <tr>
-    <td><select name=role>$selectrole</select></td>
+    <td><select name=role>|.$form->select_option($selectrole, $myconfig->{role}, undef, 1).qq|</select></td>
   </tr>
 |;
   
@@ -775,13 +730,22 @@ sub save {
 
   # no driver checked
   $form->error($locale->text('Database Driver not checked!')) unless $form->{dbdriver};
-
- 
-  # no spaces allowed in login name
-  $form->{login} =~ s/ //g;
-
-  $form->isblank("login", $locale->text('Login name missing!'));
   
+  $form->isblank("login", $locale->text('Login name missing!'));
+ 
+  # no spaces or strange characters allowed in login name
+  $form->error($locale->text('No space allowed for login!')) if $form->{login} =~ / /;
+  if ($form->{login} =~ /\W/) {
+    $login = $form->{login};
+    $login =~ s/\@//;
+    
+    $form->error($locale->text('login may only contain alphanumeric characters!')) if $login =~ /\W/;
+  }
+  
+  if ($form->{new_password} ne $form->{old_password}) {
+    $form->error($locale->text('Password may only contain alphanumeric characters!')) if $form->{new_password} =~ /\W/;
+  }
+
   # check for duplicates
   if (!$form->{edit}) {
     $temp = new User "$memberfile", "$form->{login}";
@@ -838,13 +802,13 @@ sub save {
     $form->isblank("dbport", $locale->text('Port missing!'));
     $form->isblank("dbuser", $locale->text('Dataset missing!'));
   }
-  if ($form->{dbdriver} =~ /Pg/) {
+  if ($form->{dbdriver} =~ /(Pg|Sybase)/) {
     $form->isblank("dbname", $locale->text('Dataset missing!'));
     $form->isblank("dbuser", $locale->text('Database User missing!'));
   }
-  
-  foreach $item (keys %{$form}) {
-    $myconfig->{$item} = $form->{$item};
+    
+  for (keys %{$form}) {
+    $myconfig->{$_} = $form->{$_};
   }
 
   $myconfig->{encrypted} = $form->{new_password} eq $form->{old_password};
@@ -987,7 +951,7 @@ sub delete {
   if ($myconfig{dbconnect}) {
     $myconfig{dbpasswd} = unpack 'u', $myconfig{dbpasswd};
     for (keys %myconfig) { $form->{$_} = $myconfig{$_} }
-    
+
     User->delete_login(\%$form);
   
     # delete config file for user
@@ -1045,7 +1009,6 @@ sub change_admin_password {
 <br>
 <hr size=3 noshade>
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <p>
 <input type=submit class=submit name=action value="|.$locale->text('Change Password').qq|">
@@ -1072,7 +1035,7 @@ sub change_password {
   $form->{password} = $form->{new_password};
   &create_config;
   
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}&password=$form->{password}";
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&password=$form->{password}";
 
   $form->redirect($locale->text('Password changed!'));
 
@@ -1087,7 +1050,7 @@ sub check_password {
   eval { require "$userspath/${rootname}.conf"; };
   
   if ($root->{password}) {
-   
+      
     if ($form->{password}) {
       $form->{callback} .= "&password=$form->{password}" if $form->{callback};
       if ($root->{password} ne crypt $form->{password}, 'ro') {
@@ -1099,7 +1062,7 @@ sub check_password {
       &create_config;
       
     } else {
-
+      
       if ($ENV{HTTP_USER_AGENT}) {
 	$ENV{HTTP_COOKIE} =~ s/;\s*/;/g;
 	@cookies = split /;/, $ENV{HTTP_COOKIE};
@@ -1108,14 +1071,14 @@ sub check_password {
 	  ($name,$value) = split /=/, $_, 2;
 	  $cookie{$name} = $value;
 	}
- 
+	
 	$cookie = ($form->{path} eq 'bin/lynx') ? $cookie{login} : $cookie{"SL-root login"};
 
-	if ($cookie) {
+        if ($cookie) {
 	  $form->{sessioncookie} = $cookie;
 
-	  $s = ""; 
-	  %ndx = (); 
+	  $s = "";
+	  %ndx = ();
 	  $l = length $form->{sessioncookie};
 
 	  for $i (0 .. $l - 1) {
@@ -1124,23 +1087,26 @@ sub check_password {
 	  }
 
 	  for (sort keys %ndx) {
-	    $s .= $ndx{$_}; 
+	    $s .= $ndx{$_};
 	  }
 
 	  $l = length 'root login';
 	  $login = substr($s, 0, $l);
 	  $time = substr($s, -10);
 	  $password = substr($s, $l, (length $s) - ($l + 10));
-
-	  if ((time > $time) || ($login ne 'root login') || ($root->{password} ne crypt $password, 'ro')) {
-	    &getpassword; 
-	    exit; 
-	  }
 	  
+	  if ((time > $time) || ($login ne 'root login') || ($root->{password} ne crypt $password, 'ro')) {
+	    &getpassword;
+	    exit;
+	  }
+
 	} else {
-	  &getpassword; 
+	  &getpassword;
 	  exit;
 	}
+      } else {
+	&getpassword;
+	exit;
       }
     }
   }
@@ -1172,6 +1138,14 @@ sub oracle_database_administration {
 }
 
 
+sub sybase_database_administration {
+  
+  $form->{dbdriver} = 'Sybase';
+  &dbselect_source;
+
+}
+
+
 sub dbdriver_defaults {
 
   # load some defaults for the selected driver
@@ -1186,13 +1160,19 @@ sub dbdriver_defaults {
 		             dbdefault => $sid,
 				dbhost => `hostname`,
 			 connectstring => 'SID'
+			      },
+                   'Sybase' => { dbport => '',
+		                dbuser => 'sql-ledger',
+		             dbdefault => '',
+				dbhost => '',
+			 connectstring => $locale->text('Connect to')
 			      }
                     );
 
   $driverdefaults{PgPP} = $driverdefaults{Pg};
 
   for (keys %{ $driverdefaults{Pg} }) { $form->{$_} = $driverdefaults{$form->{dbdriver}}{$_} }
-  
+
 }
   
 
@@ -1246,9 +1226,8 @@ sub dbselect_source {
 	</tr>
       </table>
 
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
+<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 <input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <br>
 
@@ -1311,14 +1290,13 @@ sub update_dataset {
     print qq|
 <table width=100%>
 <form method=post action=$form->{script}>
+|;
 
-<input type=hidden name=dbdriver value=$form->{dbdriver}>
-<input type=hidden name=dbhost value=$form->{dbhost}>
-<input type=hidden name=dbport value=$form->{dbport}>
-<input type=hidden name=dbuser value=$form->{dbuser}>
-<input type=hidden name=dbpasswd value=$form->{dbpasswd}>
-<input type=hidden name=dbdefault value=$form->{dbdefault}>
+    $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
+    $form->{nextsub} = "dbupdate";
+    $form->hide_form(qw(dbdriver dbhost dbport dbuser dbpasswd dbdefault dbupdate mextsub callback path));
 
+    print qq|
 <tr class=listheading>
   <th>|.$locale->text('The following Datasets need to be updated').qq|</th>
 </tr>
@@ -1332,19 +1310,11 @@ $upd
 <tr>
 <td>
 
-<input name=dbupdate type=hidden value="$form->{dbupdate}">
-
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
-
-<input type=hidden name=path value=$form->{path}>
-<input type=hidden name=sessionid value=$form->{sessionid}>
-
-<input type=hidden name=nextsub value=dbupdate>
-
 <hr size=3 noshade>
 
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
 </td></tr>
 </table>
@@ -1390,15 +1360,15 @@ sub create_dataset {
   # add Default at beginning
   unshift @charts, qq|<input name=chart class=radio type=radio value="Default" checked>Default|;
 
-  $selectencoding = qq|<option>
+  $selectencoding{Pg} = qq|<option>
   <option value=SQL_ASCII>ASCII
-  <option value=EUC_JP>Japanese EUC
+  <option value=UTF8>Unicode (UTF-8)
   <option value=EUC_CN>Chinese EUC
+  <option value=EUC_JP>Japanese EUC
   <option value=EUC_KR>Korean EUC
-  <option value=JOHAB>Korean EUC (Hangle base)
+  <option value=JOHAB>Korean (Hangul)
   <option value=EUC_TW>Taiwan EUC
-  <option value=UNICODE>Unicode (UTF-8)
-  <option value=MULE_INTERNAL>Mule internal type
+  <option value=KOI8>KOI8-R(U)
   <option value=LATIN1>ISO 8859-1/ECMA 94 (Latin alphabet no. 1)
   <option value=LATIN2>ISO 8859-2/ECMA 94 (Latin alphabet no. 2)
   <option value=LATIN3>ISO 8859-3/ECMA 94 (Latin alphabet no. 3)
@@ -1413,9 +1383,11 @@ sub create_dataset {
   <option value=ISO_8859_6>ISO 8859-6/ECMA 114 (Latin/Arabic)
   <option value=ISO_8859_7>ISO 8859-7/ECMA 118 (Latin/Greek)
   <option value=ISO_8859_8>ISO 8859-8/ECMA 121 (Latin/Hebrew)
-  <option value=KOI8>KOI8-R(U)
-  <option value=WIN>Windows CP1251
-  <option value=ALT>Windows CP866
+  <option value=MULE_INTERNAL>Mule internal type
+  <option value=ALT>Windows CP866 (Cyrillic)
+  <option value=WIN1250>Windows CP1250 (Central Euope)
+  <option value=WIN>Windows CP1251 (Cyrillic)
+  <option value=WIN1252>Windows CP1252 (Western European)
   <option value=WIN1256>Windows CP1256 (Arabic)
   <option value=TCVN>Windows CP1258 (Vietnamese)
   <option value=WIN874>Windows CP874 (Thai)
@@ -1457,13 +1429,20 @@ sub create_dataset {
     <td><input name=db></td>
 
   </tr>
+|;
 
+  if ($selectencoding{$form->{dbdriver}}) {
+    print qq|
   <tr>
 
     <th align=right nowrap>|.$locale->text('Multibyte Encoding').qq|</th>
-    <td><select name=encoding>$selectencoding</select></td>
+    <td><select name=encoding>$selectencoding{$form->{dbdriver}}</select></td>
 
   </tr>
+|;
+  }
+
+  print qq|
  
   <tr>
 
@@ -1498,15 +1477,16 @@ sub create_dataset {
 </table>
 |;
 
-  $form->hide_form(qw(dbdriver dbuser dbhost dbport dbpasswd dbdefault path sessionid));
+  $form->hide_form(qw(dbdriver dbuser dbhost dbport dbpasswd dbdefault path));
   
   print qq|
   
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
+<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 <input type=hidden name=nextsub value=dbcreate>
   
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
 
 </form>
@@ -1542,11 +1522,11 @@ sub dbcreate {
 .qq|
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=list_users>
 
 <p><input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 </form>
 
 
@@ -1598,10 +1578,9 @@ sub delete_dataset {
 <input type=hidden name=dbpasswd value=$form->{dbpasswd}>
 <input type=hidden name=dbdefault value=$form->{dbdefault}>
 
-<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}">
+<input name=callback type=hidden value="$form->{script}?action=list_users&path=$form->{path}">
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=dbdelete>
 
@@ -1609,6 +1588,7 @@ sub delete_dataset {
 
 <br>
 <input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main Menu').qq|">
 
   </td></tr>
 </table>
@@ -1648,11 +1628,11 @@ $form->{db} |.$locale->text('successfully deleted!')
 .qq|
 
 <input type=hidden name=path value="$form->{path}">
-<input type=hidden name=sessionid value=$form->{sessionid}>
 
 <input type=hidden name=nextsub value=list_users>
 
 <p><input type=submit class=submit name=action value="|.$locale->text('Continue').qq|">
+<input type=submit class=submit name=action value="|.$locale->text('Main').qq|">
 </form>
 
 
@@ -1667,7 +1647,7 @@ sub unlock_system {
 
   unlink "$userspath/nologin";
   
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}";
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
 
   $form->redirect($locale->text('Lockfile removed!'));
 
@@ -1679,10 +1659,12 @@ sub lock_system {
   open(FH, ">$userspath/nologin") or $form->error($locale->text('Cannot create Lock!'));
   close(FH);
   
-  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}&sessionid=$form->{sessionid}";
+  $form->{callback} = "$form->{script}?action=list_users&path=$form->{path}";
 
   $form->redirect($locale->text('Lockfile created!'));
 
 }
 
 
+sub main_menu { $form->redirect }
+
