@@ -1,24 +1,10 @@
 ######################################################################
-# SQL-Ledger Accounting
-# Copyright (c) 2000
+# SQL-Ledger ERP
+# Copyright (c) 2006
 #
 #  Author: DWS Systems Inc.
-#     Web: http://www.sql-ledger.org
+#     Web: http://www.sql-ledger.com
 #
-#  Contributors:
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 ######################################################################
 #
 # login frontend
@@ -49,11 +35,10 @@ if (-f "$form->{path}/$form->{login}_$form->{script}") {
   $form->error($@) if ($@);
 }
 
-# window title bar, user info
-$form->{titlebar} = "SQL-Ledger ".$locale->text('Version'). " $form->{version}";
+# window title bar
+$form->{titlebar} = "SQL-Ledger ".$locale->text('Version');
 
 if ($form->{action}) {
-  $form->{titlebar} .= " - $myconfig{name} - $myconfig{dbname}";
   &{ $locale->findsub($form->{action}) };
 } else {
   &login_screen;
@@ -71,9 +56,9 @@ sub login_screen {
   $form->header;
 
   if ($form->{login}) {
-   $sf = qq|function sf() { document.login.password.focus(); }|;
+   $sf = qq|function sf() { document.forms[0].password.focus(); }|;
   } else {
-   $sf = qq|function sf() { document.login.login.focus(); }|;
+   $sf = qq|function sf() { document.forms[0].login.focus(); }|;
   }
 
   print qq|
@@ -88,9 +73,9 @@ var is_nav4lo = (is_nav && (is_major <= 4));
 
 function jsp() {
   if (is_nav4lo)
-    document.login.js.value = "0"
+    document.forms[0].js.value = "0"
   else
-    document.login.js.value = "1"
+    document.forms[0].js.value = "1"
 }
 $sf
 // End -->
@@ -108,13 +93,13 @@ $sf
 <center>
 <table class=login border=3 cellpadding=20>
   <tr>
-    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0></a>
+    <td class=login align=center><a href="http://www.sql-ledger.org" target=_blank><img src=$images/sql-ledger.gif border=0></a>
 <h1 class=login align=center>|.$locale->text('Version').qq| $form->{version}
 </h1>
 
 <p>
 
-<form method=post action=$form->{script} name=login>
+<form method=post action=$form->{script}>
 
       <table width=100%>
 	<tr>
@@ -128,8 +113,6 @@ $sf
 		<th align=right>|.$locale->text('Password').qq|</th>
 		<td><input class=login type=password name=password size=30></td>
 	      </tr>
-	      <input type=hidden name=path value=$form->{path}>
-	      <input type=hidden name=js value=$form->{js}>
 	    </table>
 
 	    <br>
@@ -137,7 +120,11 @@ $sf
 	  </td>
 	</tr>
       </table>
+|;
 
+      $form->hide_form(qw(js path));
+
+      print qq|
 </form>
 
     </td>
@@ -157,11 +144,10 @@ sub selectdataset {
   if (-f "css/sql-ledger.css") {
     $form->{stylesheet} = "sql-ledger.css";
   }
-
   if (-f sql-ledger.ico) {
     $form->{favicon} = "sql-ledger.ico";
   }
-  
+
   delete $self->{sessioncookie};
   $form->header(1);
 
@@ -175,7 +161,7 @@ sub selectdataset {
 <center>
 <table class=login border=3 cellpadding=20>
   <tr>
-    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0></a>
+    <td class=login align=center><a href="http://www.sql-ledger.org" target=_blank><img src=$images/sql-ledger.gif border=0></a>
 <h1 class=login align=center>|.$locale->text('Version').qq| $form->{version}
 </h1>
 
@@ -197,12 +183,12 @@ sub selectdataset {
 		<th align=right>|.$locale->text('Password').qq|</th>
 		<td><input class=login type=password name=password size=30 value=$form->{password}></td>
 	      </tr>
-	      <input type=hidden name=js value=$form->{js}>
-	      <input type=hidden name=path value=$form->{path}>
 	      <tr>
 		<th align=right>|.$locale->text('Company').qq|</th>
 		<td>|;
 		
+		$form->hide_form(qw(js path));
+	      
 		$checked = "checked";
 		foreach $login (sort { $login{$a} cmp $login{$b} } keys %{ $login }) {
 		  print qq|
@@ -242,6 +228,7 @@ sub login {
   
   $form->error($locale->text('You did not enter a name!')) unless ($form->{login});
 
+
   if (! $form->{beenthere}) {
     open(FH, "$memberfile") or $form->error("$memberfile : $!");
     @a = <FH>;
@@ -255,7 +242,7 @@ sub login {
       }
 
       if ($item =~ /^company=/) {
-	if ($login =~ /$form->{login}\@/ && $found) {
+	if ($login =~ /^$form->{login}\@/ && $found) {
 	  ($null, $name) = split /=/, $item, 2;
 	  $login{$login} = $name;
 	}
@@ -305,15 +292,22 @@ sub login {
 
       print $locale->text('done');
 
-      print "<p><a href=menu.pl?login=$form->{login}&path=$form->{path}&action=display&main=company_logo&js=$form->{js}>".$locale->text('Continue')."</a>";
+      print "<p><a href=menu.pl?login=$form->{login}&path=$form->{path}&action=display&main=company_logo&js=$form->{js}&password=$form->{password}>".$locale->text('Continue')."</a>";
 
       exit;
     }
     
     $form->error($err[$errno]);
+  } else {
+
+    # remove stale locks
+    for (qw(dbconnect dbuser dbpasswd)) { $myconfig{$_} = $user->{$_} }
+    $myconfig{dbpasswd} = unpack 'u', $myconfig{dbpasswd};
+
+    $form->remove_locks(\%myconfig);
+
   }
 
-  $user->create_config("$userspath/$form->{login}.conf");
   $form->{timeout} = $user->{timeout};
   $form->{sessioncookie} = $user->{sessioncookie};
 
@@ -329,15 +323,7 @@ sub login {
       $form->{callback} .= "&main=company_logo";
     }
   } else {
-    if ($user->{role} eq 'user') {
-      $form->{callback} .= "&main=company_logo";
-    } else {
-      if ($user->check_recurring(\%$form)) {
-	$form->{callback} .= "&main=recurring_transactions";
-      } else {
-	$form->{callback} .= "&main=company_logo";
-      }
-    }
+    $form->{callback} .= "&main=company_logo";
   }
 
   $form->redirect;
@@ -348,8 +334,13 @@ sub login {
 
 sub logout {
 
-  $form->{callback} = "$form->{script}?path=$form->{path}&login=$form->{login}";
-  $form->redirect($locale->text('You are logged out'));
+  require "$userspath/$form->{login}.conf";
+  $myconfig{dbpasswd} = unpack 'u', $myconfig{dbpasswd};
+
+  $form->{callback} = "$form->{script}?path=$form->{path}&login=$form->{login}&endsession=1";
+  $form->remove_locks(\%myconfig);
+
+  $form->redirect;
 
 }
 
