@@ -1,27 +1,12 @@
 #!/usr/bin/perl
 #
 ######################################################################
-# SQL-Ledger Accounting
-# Copyright (C) 2001
+# SQL-Ledger ERP
+# Copyright (C) 2006
 #
-#  Author: Dieter Simader
-#   Email: dsimader@sql-ledger.org
-#     Web: http://www.sql-ledger.org
+#  Author: DWS Systems Inc.
+#     Web: http://www.sql-ledger.com
 #
-#  Contributors:
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #######################################################################
 #
 # this script sets up the terminal and runs the scripts
@@ -35,9 +20,10 @@
 $userspath = "users";
 $spool = "spool";
 $templates = "templates";
+$images = "images";
 $memberfile = "users/members";
 $sendmail = "| /usr/sbin/sendmail -t";
-%printer = ( Printer => 'lpr' );
+%printer = ();
 ########## end ###########################################
 
 
@@ -86,7 +72,7 @@ if (-e "$userspath/nologin" && $script ne 'admin.pl') {
 
 if ($form{path}) {
   $form{path} =~ s/%2f/\//gi;
-  $form{path} =~ s/\.\.\///g;
+  $form{path} =~ s/\.\.//g;
 
   if ($form{path} !~ /^bin\//) {
     print "Content-Type: text/html\n\n" if $ENV{HTTP_USER_AGENT};
@@ -119,7 +105,7 @@ if ($form{path}) {
 
   if ($form{terminal}) {
     $form{terminal} =~ s/%2f/\//gi;
-    $form{terminal} =~ s/\.\.\///g;
+    $form{terminal} =~ s/\.\.//g;
 
     $ARGV[0] = "path=bin/$form{terminal}&script=$script";
     map { $ARGV[0] .= "&${_}=$form{$_}" } keys %form;
