@@ -225,5 +225,13 @@ insert into tax (chart_id,rate) values ((select id from chart where accno = '862
 insert into tax (chart_id,rate) values ((select id from chart where accno = '8630'),0);
 insert into tax (chart_id,rate) values ((select id from chart where accno = '8650'),0);
 --
-update defaults set inventory_accno_id = (select id from chart where accno = '1410'), income_accno_id = (select id from chart where accno = '4010'), expense_accno_id = (select id from chart where accno = '7510'), fxgain_accno_id = (select id from chart where accno = '5490'), fxloss_accno_id = (select id from chart where accno = '8590'), curr = 'USD', weightunit = 'lbs';
+INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1410'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '4010'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '7510'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '5490'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '8590'));
+INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'lbs');
+INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
+--
+INSERT INTO curr (rn, curr, precision) VALUES (1,'USD',2);
 
